==> nextcloud-13.0.1.tgz: nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Združené sprístupňovanie",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
    "Server to server sharing is not enabled on this server" : "Sprístupňovanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať združené zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať združené zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na združené zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "The mountpoint name contains invalid characters." : "Meno prípojného bodu obsahuje neplatné znaky.",
    "Not allowed to create a federated share with the owner." : "Nie je povolené vytvárať združené zdieľanie s vlastníkom.",
    "Invalid or untrusted SSL certificate" : "Neplatný alebo nedôveryhodný certifikát SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie je možné overiť vo vzdialenom úložisku, heslo môže byť nesprávne",
    "Storage not valid" : "Neplatné úložisko",
    "Federated share added" : "Združené sprístupnenie pridané",
    "Couldn't add remote share" : "Nedá sa pridať vzdialené sprístupnenie",
    "Sharing %s failed, because this item is already shared with %s" : "Sprístupnenie %s zlyhalo, pretože táto položka už je prístupná pre %s",
    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %s zlyhalo, %s sa nepodarilo nájsť, server nie je pravdepodobne dostupný alebo používa vlastnoručne podpísaný certifikát.",
    "Could not find share" : "Nebolo možné nájsť sprístupnenie",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdržali ste \"%3$s\" ako vzdialené zdieľanie od %1$s (v mene %2$s) ",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Obdržali ste \"%3$s\" ako vzdialené zdieľanie od %1$s",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID, viac na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID",
    "Sharing" : "Sprístupnenie",
    "Federated file sharing" : "Združené sprístupňovanie súborov",
    "Federated Cloud Sharing" : "Sprístupnenie prostredníctvom Federated Cloud",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Adjust how people can share between servers." : "Nastavte ako môžu ľudia medzi sebou zdieľať servery.",
    "Allow users on this server to send shares to other servers" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára",
    "Federated Cloud" : "Združený Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek kto používa Nextcloud, ownCloud alebo Pydio! Len zadajte ich združené Cloud ID v dialógu pre zdieľanie. Vyzerá podobne ako person@cloud.example.com",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it so your friends can share files with you:" : "Zdieľajte to, aby mohli vaši priatelia zdieľať súbory s vami:",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Search global and public address book for users and let local users publish their data" : "Vyhľadávať používateľog v globálnom a verejnom adresári a umožniť miestnym používateľom publikovať ich dáta"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-18.0.3.tgz: nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
    "Server to server sharing is not enabled on this server" : "Sprístupňovanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať združené zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať združené zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na združené zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať združené zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať združené sprístupnenia.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Sprístupnenie %1$s zlyhalo, pretože táto položka už je prístupná pre %2$s",
    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Could not find share" : "Nebolo možné nájsť sprístupnenie",
    "Federated sharing" : "Združené sprístupňovanie",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID, viac na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID",
    "Sharing" : "Sprístupnenie",
    "Federated file sharing" : "Združené sprístupňovanie súborov",
    "Provide federated file sharing across servers" : "Poskytnúť združené sprístupňovanie súborov naprieč servermi",
    "Federated Cloud Sharing" : "Sprístupnenie prostredníctvom Federated Cloud",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Adjust how people can share between servers." : "Nastavte ako môžu ľudia medzi sebou zdieľať servery.",
    "Allow users on this server to send shares to other servers" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára",
    "Federated Cloud" : "Združený Cloud",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it so your friends can share files with you:" : "Zdieľajte to, aby mohli vaši priatelia zdieľať súbory s vami:",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "HTML Code:" : "HTML kód:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdržali ste \"%3$s\" ako vzdialené zdieľanie od %1$s (v mene %2$s) ",
    "You received \"%3$s\" as a remote share from %1$s" : "Obdržali ste \"%3$s\" ako vzdialené zdieľanie od %1$s"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
